idrlnet.architecture package
============================

.. automodule:: idrlnet.architecture
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

idrlnet.architecture.grid module
--------------------------------

.. automodule:: idrlnet.architecture.grid
   :members:
   :undoc-members:
   :show-inheritance:

idrlnet.architecture.layer module
---------------------------------

.. automodule:: idrlnet.architecture.layer
   :members:
   :undoc-members:
   :show-inheritance:

idrlnet.architecture.mlp module
-------------------------------

.. automodule:: idrlnet.architecture.mlp
   :members:
   :undoc-members:
   :show-inheritance:
